/// <reference types="bn.js" />
import { PublicKey } from '@solana/web3.js';
import { OpenOrder, OrdersAccountState, Side, StateUpdateHandler } from '../types';
import { CypherClient } from '../client';
import { BN } from '@project-serum/anchor';
import { FuturesMarketViewer, PerpMarketViewer } from '../viewers';
import { LeafNode } from '@chugach-foundation/aaob';
export interface Order {
    side: Side;
    price: number;
    quantity: number;
    orderId: BN;
    subAccountIdx: number;
    orderType: unknown;
    timestamp: BN;
    clientOrderId: BN;
    openOrdersAddress: PublicKey;
}
export declare class DerivativesOrdersAccount {
    readonly client: CypherClient;
    readonly address: PublicKey;
    state: OrdersAccountState;
    private _onStateUpdate?;
    constructor(client: CypherClient, address: PublicKey, state: OrdersAccountState, _onStateUpdate?: StateUpdateHandler<OrdersAccountState>);
    static load(client: CypherClient, address: PublicKey, onStateUpdateHandler?: StateUpdateHandler<OrdersAccountState>): Promise<DerivativesOrdersAccount>;
    getOrderIds(): BN[];
    getOrdersMap(): Map<string, OpenOrder>;
    getOrders(viewer: FuturesMarketViewer | PerpMarketViewer): Promise<Order[]>;
    getPriceQuantity(viewer: FuturesMarketViewer | PerpMarketViewer, leafNode: LeafNode): {
        price: number;
        quantity: number;
    };
    getBaseTokenFree(subAcctIdx: number, baseDecimals: number): number;
    getQuoteTokenFree(subAcctIdx: number, quoteDecimals: number): number;
    subscribe(): void;
    unsubscribe(): Promise<void>;
}
