"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PerpetualMarket = void 0;
const web3_js_1 = require("@solana/web3.js");
const instructions_1 = require("../instructions");
const utils_1 = require("../utils");
class PerpetualMarket {
    constructor(client, address, state, _onStateUpdate) {
        this.client = client;
        this.address = address;
        this.state = state;
        this._onStateUpdate = _onStateUpdate;
        _onStateUpdate && this.subscribe();
    }
    static async create(client, authority, clearing, cacheAccount, quotePool, oracleProducts, args) {
        const [market, marketBump] = (0, utils_1.deriveMarketAddress)(args.marketName, client.cypherPID);
        args.marketBump = marketBump;
        const { orderbook, eventQueue, bids, asks, ixs, signers } = await (0, instructions_1.makeCreateMarketAccountsIxs)(client);
        const tx = new web3_js_1.Transaction();
        tx.add(...ixs);
        await client.sendAndConfirm(tx, signers);
        await client.methods
            .createPerpMarket({
            ...args,
            marketType: args.marketType
        })
            .accountsStrict({
            clearing,
            cacheAccount,
            market,
            oracleProducts,
            quotePool: quotePool.address,
            orderbook,
            bids,
            asks,
            eventQueue,
            authority,
            payer: client.walletPubkey,
            systemProgram: web3_js_1.SystemProgram.programId,
            rent: web3_js_1.SYSVAR_RENT_PUBKEY
        })
            .rpc();
        return market;
    }
    static async load(client, address, onStateUpdateHandler) {
        const state = (await client.accounts.perpetualMarket.fetchNullable(address));
        return new PerpetualMarket(client, address, state, onStateUpdateHandler);
    }
    static async loadAll(client) {
        const queryResult = await client.accounts.perpetualMarket.all();
        return queryResult.map((result) => new PerpetualMarket(client, result.publicKey, result.account));
    }
    subscribe() {
        this.client.accounts.perpetualMarket
            .subscribe(this.address)
            .on('change', (state) => {
            this.state = state;
            // todo: check if dexMarkets need to be reloaded.(market listing/delisting)
            if (this._onStateUpdate) {
                this._onStateUpdate(this.state);
            }
        });
    }
    async unsubscribe() {
        await this.client.accounts.perpetualMarket.unsubscribe(this.address);
    }
}
exports.PerpetualMarket = PerpetualMarket;
//# sourceMappingURL=perpMarket.js.map