"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CypherClient = void 0;
const web3_js_1 = require("@solana/web3.js");
const anchor_1 = require("@project-serum/anchor");
const faucet_1 = require("./faucet");
const constants_1 = require("../constants");
const cypher_json_1 = __importDefault(require("../generated/idl/cypher.json"));
class CypherClient {
    constructor(cluster, rpcEndpoint, wallet, confirmOpts = anchor_1.AnchorProvider.defaultOptions()) {
        this.cluster = cluster;
        const provider = {
            connection: new web3_js_1.Connection(rpcEndpoint, confirmOpts.commitment)
        };
        this._program = new anchor_1.Program(cypher_json_1.default, constants_1.CONFIGS[this.cluster].CYPHER_PID, provider);
        if (wallet) {
            this.connectWallet(wallet, rpcEndpoint, confirmOpts);
        }
    }
    connectWallet(wallet, rpcEndpoint, confirmOpts = anchor_1.AnchorProvider.defaultOptions()) {
        const provider = new anchor_1.AnchorProvider(this.connection, wallet, confirmOpts);
        this._program = new anchor_1.Program(cypher_json_1.default, constants_1.CONFIGS[this.cluster].CYPHER_PID, provider);
        if (this.cluster !== 'mainnet-beta') {
            this.faucet = new faucet_1.FaucetClient(this.cluster, rpcEndpoint, wallet, confirmOpts);
        }
    }
    get _provider() {
        return this._program.provider;
    }
    get anchorProvider() {
        const provider = this._program.provider;
        if (provider.wallet) {
            return provider;
        }
    }
    get connection() {
        return this._provider.connection;
    }
    get methods() {
        return this._program.methods;
    }
    get accounts() {
        return this._program.account;
    }
    get isWalletConnected() {
        return !!this.anchorProvider;
    }
    get walletPubkey() {
        return this.anchorProvider?.wallet.publicKey;
    }
    get cypherPID() {
        return constants_1.CONFIGS[this.cluster].CYPHER_PID;
    }
    get dexPID() {
        return constants_1.CONFIGS[this.cluster].DEX_PID;
    }
    get quoteMint() {
        return constants_1.CONFIGS[this.cluster].QUOTE_MINT;
    }
    addEventListener(eventName, 
    // eslint-disable-next-line
    callback) {
        return this._program.addEventListener(eventName, callback);
    }
    async removeEventListener(listener) {
        return await this._program.removeEventListener(listener);
    }
    async sendAndConfirm(tx, signers, opts) {
        return this.anchorProvider?.sendAndConfirm(tx, signers, opts);
    }
    async sendAndConfirmIxs(ixs, signers, opts) {
        const tx = new web3_js_1.Transaction();
        tx.add(...ixs);
        return this.sendAndConfirm(tx, signers, opts);
    }
}
exports.CypherClient = CypherClient;
//# sourceMappingURL=index.js.map