"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deriveSerumOrdersAccountAddress = exports.deriveOrdersAccountAddress = exports.deriveSubAccountAddress = exports.deriveAccountAddress = exports.deriveOracleProductsAddress = exports.deriveMarketAddress = exports.derivePoolNodeVaultSigner = exports.derivePoolNodeVaultAddress = exports.derivePoolNodeAddress = exports.derivePoolAddress = exports.derivePrivateClearingAddress = exports.derivePublicClearingAddress = exports.getDexVaultSigner = void 0;
const web3_js_1 = require("@solana/web3.js");
const anchor_1 = require("@project-serum/anchor");
const getDexVaultSigner = (dexMarket, vaultSignerNonce, dexPID) => {
    return web3_js_1.PublicKey.createProgramAddressSync([dexMarket.toBuffer(), vaultSignerNonce.toArrayLike(Buffer, 'le', 8)], dexPID);
};
exports.getDexVaultSigner = getDexVaultSigner;
const derivePublicClearingAddress = (cypherPID) => {
    const B_CLEARING = anchor_1.utils.bytes.utf8.encode('CYPHER_CLEARING');
    return anchor_1.utils.publicKey.findProgramAddressSync([B_CLEARING, Buffer.from([0])], cypherPID);
};
exports.derivePublicClearingAddress = derivePublicClearingAddress;
const derivePrivateClearingAddress = (clearingNumber, cypherPID) => {
    const B_CLEARING = anchor_1.utils.bytes.utf8.encode('CYPHER_CLEARING');
    return anchor_1.utils.publicKey.findProgramAddressSync([B_CLEARING, Buffer.from([1]), Buffer.from([clearingNumber])], cypherPID);
};
exports.derivePrivateClearingAddress = derivePrivateClearingAddress;
const derivePoolAddress = (poolName, cypherPID) => {
    const B_POOL = anchor_1.utils.bytes.utf8.encode('CYPHER_POOL');
    return anchor_1.utils.publicKey.findProgramAddressSync([B_POOL, Buffer.from(poolName)], cypherPID);
};
exports.derivePoolAddress = derivePoolAddress;
const derivePoolNodeAddress = (pool, nodeNumber, cypherPID) => {
    const B_POOL_NODE = anchor_1.utils.bytes.utf8.encode('CYPHER_POOL_NODE');
    return anchor_1.utils.publicKey.findProgramAddressSync([B_POOL_NODE, pool.toBuffer(), Buffer.from([nodeNumber])], cypherPID);
};
exports.derivePoolNodeAddress = derivePoolNodeAddress;
const derivePoolNodeVaultAddress = (poolNode, cypherPID) => {
    const B_POOL_VAULT = anchor_1.utils.bytes.utf8.encode('CYPHER_POOL_NODE_VAULT');
    return anchor_1.utils.publicKey.findProgramAddressSync([B_POOL_VAULT, poolNode.toBuffer()], cypherPID);
};
exports.derivePoolNodeVaultAddress = derivePoolNodeVaultAddress;
const derivePoolNodeVaultSigner = (poolNode, cypherPID) => {
    const B_POOL_NODE_VAULT_SIGNER = anchor_1.utils.bytes.utf8.encode('CYPHER_POOL_NODE_VAULT_SIGNER');
    return anchor_1.utils.publicKey.findProgramAddressSync([B_POOL_NODE_VAULT_SIGNER, poolNode.toBuffer()], cypherPID);
};
exports.derivePoolNodeVaultSigner = derivePoolNodeVaultSigner;
const deriveMarketAddress = (marketName, cypherPID) => {
    const B_CYPHER_MARKET = anchor_1.utils.bytes.utf8.encode('CYPHER_MARKET');
    return anchor_1.utils.publicKey.findProgramAddressSync([B_CYPHER_MARKET, Buffer.from(marketName)], cypherPID);
};
exports.deriveMarketAddress = deriveMarketAddress;
const deriveOracleProductsAddress = (symbol, cypherPID) => {
    const B_CYPHER_MARKET = anchor_1.utils.bytes.utf8.encode('CYPHER_ORACLE_PRODUCTS');
    return anchor_1.utils.publicKey.findProgramAddressSync([B_CYPHER_MARKET, Buffer.from(symbol)], cypherPID);
};
exports.deriveOracleProductsAddress = deriveOracleProductsAddress;
const deriveAccountAddress = (authority, accountNumber, cypherPID) => {
    const B_CYPHER_ACCOUNT = anchor_1.utils.bytes.utf8.encode('CYPHER_ACCOUNT');
    return anchor_1.utils.publicKey.findProgramAddressSync([B_CYPHER_ACCOUNT, authority.toBuffer(), Buffer.from([accountNumber])], cypherPID);
};
exports.deriveAccountAddress = deriveAccountAddress;
const deriveSubAccountAddress = (masterAccount, accountNumber, cypherPID) => {
    const B_CYPHER_SUB_ACCOUNT = anchor_1.utils.bytes.utf8.encode('CYPHER_SUB_ACCOUNT');
    return anchor_1.utils.publicKey.findProgramAddressSync([
        B_CYPHER_SUB_ACCOUNT,
        masterAccount.toBuffer(),
        Buffer.from([accountNumber])
    ], cypherPID);
};
exports.deriveSubAccountAddress = deriveSubAccountAddress;
const deriveOrdersAccountAddress = (masterAccount, market, cypherPID) => {
    const B_ORDERS_ACCOUNT = anchor_1.utils.bytes.utf8.encode('CYPHER_ORDERS_ACCOUNT');
    return anchor_1.utils.publicKey.findProgramAddressSync([B_ORDERS_ACCOUNT, market.toBuffer(), masterAccount.toBuffer()], cypherPID);
};
exports.deriveOrdersAccountAddress = deriveOrdersAccountAddress;
const deriveSerumOrdersAccountAddress = (dexMarket, masterAccount, subAccount, cypherPID) => {
    const B_OPEN_ORDERS = anchor_1.utils.bytes.utf8.encode('OPEN_ORDERS');
    return anchor_1.utils.publicKey.findProgramAddressSync([
        B_OPEN_ORDERS,
        dexMarket.toBuffer(),
        masterAccount.toBuffer(),
        subAccount.toBuffer()
    ], cypherPID);
};
exports.deriveSerumOrdersAccountAddress = deriveSerumOrdersAccountAddress;
//# sourceMappingURL=pda.js.map